@@ -4,8 +4,8 @@ describe 'tempest' do
   shared_examples 'tempest' do
 
     let :pre_condition do
-      "include ::glance
-       include ::neutron"
+      "include glance
+       include neutron"
     end
 
     context 'without parameters' do
@@ -358,8 +358,8 @@ describe 'tempest' do
 
   shared_examples 'tempest with plugins packages' do
     let :pre_condition do
-      "include ::glance
-       include ::neutron"
+      "include glance
+       include neutron"
     end
 
     context 'with when managing tests packages for keystone (required service)' do
@@ -403,7 +403,6 @@ describe 'tempest' do
 
       describe "should install neutron and *aas tests packages" do
         it { expect { is_expected.to contain_package('python-neutron-tests') } }
-        it { expect { is_expected.to contain_package('python-neutron-fwaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-vpnaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-dynamic-routing-tests') } }
         it { expect { is_expected.to contain_package('python-networking-l2gw-tests-tempest') } }
